@@ -17,7 +17,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-import sys
 import unittest
 
 from .base import TestBase
@@ -36,6 +35,9 @@ class TestNetworkd(TestBase):
         self.assert_networkd({'br0.network': '''[Match]
 Name=br0
 
+[Link]
+MACAddress=00:01:02:03:04:05
+
 [Network]
 DHCP=ipv4
 LinkLocalAddressing=ipv6
@@ -215,7 +217,7 @@ UseMTU=true
       dhcp4: yes''')
         self.assert_nm(None, '''[keyfile]
 # devices managed by networkd
-unmanaged-devices+=interface-name:mybr,interface-name:eth42,interface-name:eth43,''')
+unmanaged-devices+=interface-name:eth42,interface-name:eth43,interface-name:mybr,''')
 
     def test_bridge_components(self):
         self.generate('''network:
@@ -359,7 +361,7 @@ id=netplan-br0
 type=bridge
 interface-name=br0
 
-[802-3-ethernet]
+[ethernet]
 cloned-mac-address=00:01:02:03:04:05
 
 [ipv4]
@@ -713,4 +715,3 @@ class TestConfigErrors(TestBase):
         port-priority:
           eno1: 257
       dhcp4: true''', expect_fail=True)
-
