@@ -225,8 +225,8 @@ unmanaged-devices+=interface-name:green,''')
       macaddress: 00:01:02:03:04:05
       dhcp4: true''')
 
-        self.assert_networkd({'def1.network': ND_DHCP4 % 'green',
-                              'def1.link': '[Match]\nOriginalName=green\n\n[Link]\nWakeOnLan=off\nMACAddress=00:01:02:03:04:05\n'
+        self.assert_networkd({'def1.network': (ND_DHCP4 % 'green')
+                              .replace('[Network]', '[Link]\nMACAddress=00:01:02:03:04:05\n\n[Network]')
                               })
         self.assert_networkd_udev(None)
 
@@ -354,8 +354,6 @@ interface-name=eth1
 
 [ethernet]
 wake-on-lan=0
-
-[802-3-ethernet]
 mtu=1280
 
 [ipv4]
@@ -442,13 +440,7 @@ method=ignore
       macaddress: 00:01:02:03:04:05
       dhcp4: true''')
 
-        self.assert_networkd({'eth0.link': '''[Match]
-OriginalName=eth0
-
-[Link]
-WakeOnLan=off
-MACAddress=00:01:02:03:04:05
-'''})
+        self.assert_networkd(None)
 
         self.assert_nm({'eth0': '''[connection]
 id=netplan-eth0
@@ -457,8 +449,6 @@ interface-name=eth0
 
 [ethernet]
 wake-on-lan=0
-
-[802-3-ethernet]
 cloned-mac-address=00:01:02:03:04:05
 
 [ipv4]
@@ -575,8 +565,6 @@ type=ethernet
 
 [ethernet]
 wake-on-lan=0
-
-[802-3-ethernet]
 mac-address=11:22:33:44:55:66
 
 [ipv4]
@@ -715,8 +703,6 @@ interface-name=engreen
 
 [ethernet]
 wake-on-lan=0
-
-[802-3-ethernet]
 mac-address=00:11:22:33:44:55
 
 [ipv4]
