@@ -30,6 +30,7 @@ import tempfile
 import unittest
 import shutil
 import gi
+import glob
 
 # make sure we point to libnetplan properly.
 os.environ.update({'LD_LIBRARY_PATH': '.:{}'.format(os.environ.get('LD_LIBRARY_PATH'))})
@@ -51,39 +52,35 @@ def resolved_in_use():
 class IntegrationTestsBase(unittest.TestCase):
     '''Common functionality for network test cases
 
-    setUp() creates two test wlan devices, one for a simulated access point
-    (self.dev_w_ap), the other for a simulated client device
-    (self.dev_w_client), and two test ethernet devices (self.dev_e_{ap,client}
-    and self.dev_e2_{ap,client}.
+    setUp() creates two test ethernet devices (self.dev_e_{ap,client} and
+    self.dev_e2_{ap,client}.
 
-    Each test should call self.setup_ap() or self.setup_eth() with the desired
-    configuration.
+    Each test should call self.setup_eth() with the desired configuration.
     '''
     @classmethod
     def setUpClass(klass):
+        shutil.rmtree('/etc/netplan', ignore_errors=True)
+        os.makedirs('/etc/netplan', exist_ok=True)
+        # Try to keep autopkgtest's management network (eth0/ens3) up and
+        # configured. It should be running all the time, independently of netplan
+        os.makedirs('/etc/systemd/network', exist_ok=True)
+        with open('/etc/systemd/network/20-wired.network', 'w') as f:
+            f.write('[Match]\nName=eth0 en*\n\n[Network]\nDHCP=ipv4')
+
         # ensure NM can manage our fake eths
         os.makedirs('/run/udev/rules.d', exist_ok=True)
-
         with open('/run/udev/rules.d/99-nm-veth-test.rules', 'w') as f:
             f.write('ENV{ID_NET_DRIVER}=="veth", ENV{INTERFACE}=="eth42|eth43", ENV{NM_UNMANAGED}="0"\n')
         subprocess.check_call(['udevadm', 'control', '--reload'])
 
-        # ensure we have this so that iw works
-        try:
-            subprocess.check_call(['modprobe', 'cfg80211'])
-            # set regulatory domain "EU", so that we can use 80211.a 5 GHz channels
-            out = subprocess.check_output(['iw', 'reg', 'get'], universal_newlines=True)
-            m = re.match(r'^(?:global\n)?country (\S+):', out)
-            assert m
-            klass.orig_country = m.group(1)
-            subprocess.check_call(['iw', 'reg', 'set', 'EU'])
-        except Exception:
-            raise unittest.SkipTest("cfg80211 (wireless) is unavailable, can't test")
-
+        os.makedirs('/etc/NetworkManager/conf.d', exist_ok=True)
+        with open('/etc/NetworkManager/conf.d/99-test-ignore.conf', 'w') as f:
+            f.write('[keyfile]\nunmanaged-devices+=interface-name:eth0,interface-name:en*,interface-name:veth42,interface-name:veth43')
+        subprocess.check_call(['netplan', 'apply'])
+        subprocess.call(['/lib/systemd/systemd-networkd-wait-online', '--quiet', '--timeout=30'])
 
     @classmethod
     def tearDownClass(klass):
-        subprocess.check_call(['iw', 'reg', 'set', klass.orig_country])
         try:
             os.remove('/run/NetworkManager/conf.d/test-blacklist.conf')
         except FileNotFoundError:
@@ -103,17 +100,22 @@ class IntegrationTestsBase(unittest.TestCase):
         shutil.rmtree('/etc/netplan', ignore_errors=True)
         shutil.rmtree('/run/NetworkManager', ignore_errors=True)
         shutil.rmtree('/run/systemd/network', ignore_errors=True)
+        for f in glob.glob('/run/systemd/system/netplan-*'):
+            os.remove(f)
+        for f in glob.glob('/run/systemd/system/**/netplan-*'):
+            os.remove(f)
+        subprocess.call(['systemctl', 'daemon-reload'])
         try:
             os.remove('/run/systemd/generator/netplan.stamp')
         except FileNotFoundError:
             pass
+        # Keep the management network (eth0/ens3 from 20-wired.network) up
+        subprocess.check_call(['systemctl', 'restart', 'systemd-networkd'])
 
     @classmethod
     def create_devices(klass):
-        '''Create Access Point and Client devices with mac80211_hwsim and veth'''
+        '''Create Access Point and Client devices with veth'''
 
-        if os.path.exists('/sys/module/mac80211_hwsim'):
-            raise SystemError('mac80211_hwsim module already loaded')
         if os.path.exists('/sys/class/net/eth42'):
             raise SystemError('eth42 interface already exists')
 
@@ -124,15 +126,20 @@ class IntegrationTestsBase(unittest.TestCase):
         klass.dev_e_client = 'eth42'
         klass.dev_e_ap_ip4 = '192.168.5.1/24'
         klass.dev_e_ap_ip6 = '2600::1/64'
-        out = subprocess.check_output(['ip', '-br', 'link', 'show', 'dev', 'eth42'],
-                                      universal_newlines=True)
-        klass.dev_e_client_mac = out.split()[2]
         subprocess.check_call(['ip', 'link', 'add', 'name', 'eth43', 'type',
                                'veth', 'peer', 'name', 'veth43'])
         klass.dev_e2_ap = 'veth43'
         klass.dev_e2_client = 'eth43'
         klass.dev_e2_ap_ip4 = '192.168.6.1/24'
         klass.dev_e2_ap_ip6 = '2601::1/64'
+        # Creation of the veths introduces a race with newer versions of
+        # systemd, as it  will change the initial MAC address after the device
+        # was created and networkd took control. Give it some time, so we read
+        # the correct MAC address
+        time.sleep(0.1)
+        out = subprocess.check_output(['ip', '-br', 'link', 'show', 'dev', 'eth42'],
+                                      universal_newlines=True)
+        klass.dev_e_client_mac = out.split()[2]
         out = subprocess.check_output(['ip', '-br', 'link', 'show', 'dev', 'eth43'],
                                       universal_newlines=True)
         klass.dev_e2_client_mac = out.split()[2]
@@ -143,28 +150,6 @@ class IntegrationTestsBase(unittest.TestCase):
         with open('/run/NetworkManager/conf.d/11-globally-managed-devices.conf', 'w') as f:
             f.write('[keyfile]\nunmanaged-devices=')
 
-        # create virtual wlan devs
-        before_wlan = set([c for c in os.listdir('/sys/class/net') if c.startswith('wlan')])
-        subprocess.check_call(['modprobe', 'mac80211_hwsim'])
-        # wait 5 seconds for fake devices to appear
-        timeout = 50
-        while timeout > 0:
-            after_wlan = set([c for c in os.listdir('/sys/class/net') if c.startswith('wlan')])
-            if len(after_wlan) - len(before_wlan) >= 2:
-                break
-            timeout -= 1
-            time.sleep(0.1)
-        else:
-            raise SystemError('timed out waiting for fake devices to appear')
-
-        devs = list(after_wlan - before_wlan)
-        klass.dev_w_ap = devs[0]
-        klass.dev_w_client = devs[1]
-
-        # don't let NM trample over our fake AP
-        with open('/run/NetworkManager/conf.d/test-blacklist.conf', 'w') as f:
-            f.write('[main]\nplugins=keyfile\n[keyfile]\nunmanaged-devices+=nptestsrv,%s\n' % klass.dev_w_ap)
-
     @classmethod
     def shutdown_devices(klass):
         '''Remove test devices'''
@@ -175,14 +160,10 @@ class IntegrationTestsBase(unittest.TestCase):
         klass.dev_e_client = None
         klass.dev_e2_ap = None
         klass.dev_e2_client = None
-        klass.dev_w_ap = None
-        klass.dev_w_client = None
 
         subprocess.call(['ip', 'link', 'del', 'dev', 'mybr'],
                         stderr=subprocess.PIPE)
 
-        subprocess.check_call(['rmmod', 'mac80211_hwsim'])
-
     def setUp(self):
         '''Create test devices and workdir'''
 
@@ -198,25 +179,6 @@ class IntegrationTestsBase(unittest.TestCase):
         with open(self.entropy_file, 'wb') as f:
             f.write(b'012345678901234567890')
 
-    def setup_ap(self, hostapd_conf, ipv6_mode):
-        '''Set up simulated access point
-
-        On self.dev_w_ap, run hostapd with given configuration. Setup dnsmasq
-        according to ipv6_mode, see start_dnsmasq().
-
-        This is torn down automatically at the end of the test.
-        '''
-
-        # give our AP an IP
-        subprocess.check_call(['ip', 'a', 'flush', 'dev', self.dev_w_ap])
-        if ipv6_mode is not None:
-            subprocess.check_call(['ip', 'a', 'add', self.dev_e_ap_ip6, 'dev', self.dev_w_ap])
-        else:
-            subprocess.check_call(['ip', 'a', 'add', self.dev_e_ap_ip4, 'dev', self.dev_w_ap])
-
-        self.start_hostapd(hostapd_conf)
-        self.start_dnsmasq(ipv6_mode, self.dev_w_ap)
-
     def setup_eth(self, ipv6_mode, start_dnsmasq=True):
         '''Set up simulated ethernet router
 
@@ -237,6 +199,7 @@ class IntegrationTestsBase(unittest.TestCase):
         subprocess.check_call(['ip', 'link', 'set', self.dev_e2_ap, 'up'])
         if start_dnsmasq:
             self.start_dnsmasq(ipv6_mode, self.dev_e_ap)
+            self.start_dnsmasq(ipv6_mode, self.dev_e2_ap)
 
     #
     # Internal implementation details
@@ -269,19 +232,6 @@ class IntegrationTestsBase(unittest.TestCase):
 
         assert timeout > 0, 'Timed out waiting for "%s":\n------------\n%s\n-------\n' % (string, log)
 
-    def start_hostapd(self, conf):
-        hostapd_conf = os.path.join(self.workdir, 'hostapd.conf')
-        with open(hostapd_conf, 'w') as f:
-            f.write('interface=%s\ndriver=nl80211\n' % self.dev_w_ap)
-            f.write(conf)
-
-        log = os.path.join(self.workdir, 'hostapd.log')
-        p = subprocess.Popen(['hostapd', '-e', self.entropy_file, '-f', log, hostapd_conf],
-                             stdout=subprocess.PIPE)
-        self.addCleanup(p.wait)
-        self.addCleanup(p.terminate)
-        self.poll_text(log, '' + self.dev_w_ap + ': AP-ENABLED', 500)
-
     def start_dnsmasq(self, ipv6_mode, iface):
         '''Start dnsmasq.
 
@@ -343,24 +293,18 @@ class IntegrationTestsBase(unittest.TestCase):
         if 'bond' not in iface:
             self.assertIn('state UP', out)
 
-        if iface == self.dev_w_client:
-            out = subprocess.check_output(['iw', 'dev', iface, 'link'],
-                                          universal_newlines=True)
-            # self.assertIn('Connected to ' + self.mac_w_ap, out)
-            self.assertIn('SSID: fake net', out)
-
     def generate_and_settle(self):
         '''Generate config, launch and settle NM and networkd'''
 
         # regenerate netplan config
-        out = subprocess.check_output(['netplan', 'apply'], universal_newlines=True)
+        out = subprocess.check_output(['netplan', 'apply'], stderr=subprocess.STDOUT, universal_newlines=True)
         if 'Run \'systemctl daemon-reload\' to reload units.' in out:
             self.fail('systemd units changed without reload')
         # start NM so that we can verify that it does not manage anything
         subprocess.check_call(['systemctl', 'start', '--no-block', 'NetworkManager.service'])
         # wait until networkd is done
         if self.is_active('systemd-networkd.service'):
-            if subprocess.call(['/lib/systemd/systemd-networkd-wait-online', '--quiet', '--timeout=20']) != 0:
+            if subprocess.call(['/lib/systemd/systemd-networkd-wait-online', '--quiet', '--timeout=30']) != 0:
                 subprocess.call(['journalctl', '-b', '--no-pager', '-t', 'systemd-networkd'])
                 st = subprocess.check_output(['networkctl'], stderr=subprocess.PIPE, universal_newlines=True)
                 st_e = subprocess.check_output(['networkctl', 'status', self.dev_e_client],
@@ -408,3 +352,110 @@ class IntegrationTestsBase(unittest.TestCase):
         p = subprocess.Popen(['systemctl', 'is-active', unit], stdout=subprocess.PIPE)
         out = p.communicate()[0]
         return p.returncode == 0 or out.startswith(b'activating')
+
+
+class IntegrationTestsWifi(IntegrationTestsBase):
+    '''Common functionality for network test cases
+
+    setUp() creates two test wlan devices, one for a simulated access point
+    (self.dev_w_ap), the other for a simulated client device
+    (self.dev_w_client), and two test ethernet devices (self.dev_e_{ap,client}
+    and self.dev_e2_{ap,client}.
+
+    Each test should call self.setup_ap() or self.setup_eth() with the desired
+    configuration.
+    '''
+    @classmethod
+    def setUpClass(klass):
+        super().setUpClass()
+        # ensure we have this so that iw works
+        try:
+            subprocess.check_call(['modprobe', 'cfg80211'])
+            # set regulatory domain "EU", so that we can use 80211.a 5 GHz channels
+            out = subprocess.check_output(['iw', 'reg', 'get'], universal_newlines=True)
+            m = re.match(r'^(?:global\n)?country (\S+):', out)
+            assert m
+            klass.orig_country = m.group(1)
+            subprocess.check_call(['iw', 'reg', 'set', 'EU'])
+        except Exception:
+            raise unittest.SkipTest("cfg80211 (wireless) is unavailable, can't test")
+
+    @classmethod
+    def tearDownClass(klass):
+        subprocess.check_call(['iw', 'reg', 'set', klass.orig_country])
+        super().tearDownClass()
+
+    @classmethod
+    def create_devices(klass):
+        '''Create Access Point and Client devices with mac80211_hwsim and veth'''
+        if os.path.exists('/sys/module/mac80211_hwsim'):
+            raise SystemError('mac80211_hwsim module already loaded')
+        super().create_devices()
+        # create virtual wlan devs
+        before_wlan = set([c for c in os.listdir('/sys/class/net') if c.startswith('wlan')])
+        subprocess.check_call(['modprobe', 'mac80211_hwsim'])
+        # wait 5 seconds for fake devices to appear
+        timeout = 50
+        while timeout > 0:
+            after_wlan = set([c for c in os.listdir('/sys/class/net') if c.startswith('wlan')])
+            if len(after_wlan) - len(before_wlan) >= 2:
+                break
+            timeout -= 1
+            time.sleep(0.1)
+        else:
+            raise SystemError('timed out waiting for fake devices to appear')
+
+        devs = list(after_wlan - before_wlan)
+        klass.dev_w_ap = devs[0]
+        klass.dev_w_client = devs[1]
+
+        # don't let NM trample over our fake AP
+        with open('/run/NetworkManager/conf.d/test-blacklist.conf', 'w') as f:
+            f.write('[main]\nplugins=keyfile\n[keyfile]\nunmanaged-devices+=nptestsrv,%s\n' % klass.dev_w_ap)
+
+    @classmethod
+    def shutdown_devices(klass):
+        '''Remove test devices'''
+        super().shutdown_devices()
+        klass.dev_w_ap = None
+        klass.dev_w_client = None
+        subprocess.check_call(['rmmod', 'mac80211_hwsim'])
+
+    def start_hostapd(self, conf):
+        hostapd_conf = os.path.join(self.workdir, 'hostapd.conf')
+        with open(hostapd_conf, 'w') as f:
+            f.write('interface=%s\ndriver=nl80211\n' % self.dev_w_ap)
+            f.write(conf)
+
+        log = os.path.join(self.workdir, 'hostapd.log')
+        p = subprocess.Popen(['hostapd', '-e', self.entropy_file, '-f', log, hostapd_conf],
+                             stdout=subprocess.PIPE)
+        self.addCleanup(p.wait)
+        self.addCleanup(p.terminate)
+        self.poll_text(log, '' + self.dev_w_ap + ': AP-ENABLED', 500)
+
+    def setup_ap(self, hostapd_conf, ipv6_mode):
+        '''Set up simulated access point
+
+        On self.dev_w_ap, run hostapd with given configuration. Setup dnsmasq
+        according to ipv6_mode, see start_dnsmasq().
+
+        This is torn down automatically at the end of the test.
+        '''
+        # give our AP an IP
+        subprocess.check_call(['ip', 'a', 'flush', 'dev', self.dev_w_ap])
+        if ipv6_mode is not None:
+            subprocess.check_call(['ip', 'a', 'add', self.dev_e_ap_ip6, 'dev', self.dev_w_ap])
+        else:
+            subprocess.check_call(['ip', 'a', 'add', self.dev_e_ap_ip4, 'dev', self.dev_w_ap])
+        self.start_hostapd(hostapd_conf)
+        self.start_dnsmasq(ipv6_mode, self.dev_w_ap)
+
+    def assert_iface_up(self, iface, expected_ip_a=None, unexpected_ip_a=None):
+        '''Assert that client interface is up'''
+        super().assert_iface_up(iface, expected_ip_a, unexpected_ip_a)
+        if iface == self.dev_w_client:
+            out = subprocess.check_output(['iw', 'dev', iface, 'link'],
+                                          universal_newlines=True)
+            # self.assertIn('Connected to ' + self.mac_w_ap, out)
+            self.assertIn('SSID: fake net', out)
