@@ -32,7 +32,6 @@ class _CommonTests():
 
     def test_eth_mtu(self):
         self.setup_eth(None)
-        self.start_dnsmasq(None, self.dev_e2_ap)
         with open(self.config, 'w') as f:
             f.write('''network:
   renderer: %(r)s
@@ -55,7 +54,6 @@ class _CommonTests():
 
     def test_eth_mac(self):
         self.setup_eth(None)
-        self.start_dnsmasq(None, self.dev_e2_ap)
         with open(self.config, 'w') as f:
             f.write('''network:
   renderer: %(r)s
@@ -72,7 +70,7 @@ class _CommonTests():
                              ['master'])
         out = subprocess.check_output(['ip', 'link', 'show', self.dev_e2_client],
                                       universal_newlines=True)
-        self.assertTrue('ether 00:01:02:03:04:05' in out)
+        self.assertIn('ether 00:01:02:03:04:05', out)
         subprocess.check_call(['ip', 'link', 'set', self.dev_e2_client,
                                'address', self.dev_e2_client_mac])
 
@@ -81,7 +79,6 @@ class _CommonTests():
 
         Interface globbing was introduced as of NM 1.14+'''
         self.setup_eth(None)
-        self.start_dnsmasq(None, self.dev_e2_ap)
         with open(self.config, 'w') as f:
             f.write('''network:
   renderer: %(r)s
@@ -152,7 +149,7 @@ class _CommonTests():
         elif resolved_in_use():
             sys.stdout.write('[resolved] ')
             sys.stdout.flush()
-            out = subprocess.check_output(['systemd-resolve', '--status'], universal_newlines=True)
+            out = subprocess.check_output(['resolvectl', 'status'], universal_newlines=True)
             self.assertIn('DNS Servers: 172.1.2.3', out)
             self.assertIn('fakesuffix', out)
         else:
@@ -175,7 +172,6 @@ class _CommonTests():
       addresses: ["172.16.7.2/30", "4321:AAAA::99/80"]
       dhcp4: yes
 ''' % {'r': self.backend, 'ec': self.dev_e_client, 'e2c': self.dev_e2_client})
-        self.start_dnsmasq(None, self.dev_e2_ap)
         self.generate_and_settle()
         if self.backend == 'NetworkManager':
             self.nm_online_full(self.dev_e2_client)
